@@ -30,8 +30,10 @@ fn main() {
     let manager = openstack::compute::v2::servers(&session);
     let server = manager.get(env::args().nth(1).expect("Provide a server ID"))
         .expect("Cannot get a server");
-    println!("ID = {}, Name = {}, Status = {}",
+    println!("ID = {}, Name = {}, Status = {:?}",
              server.id(), server.name(), server.status());
+    println!("Links: flavor = {}, image = {}",
+             server.flavor().id(), server.image().id());
 }
 
 #[cfg(not(feature = "compute"))]
