@@ -17,26 +17,22 @@
 use std::fmt::Debug;
 
 use hyper::{Client, Url};
+use hyper::header::Headers;
+use hyper::method::Method;
 
-use super::super::{ApiResult, Session};
+use super::super::ApiResult;
+use super::super::service::RequestBuilder;
 
 
-/// Trait for authentication token implementations.
-pub trait Token: Clone + Debug + Into<String> {
-    /// Check whether the token needs refreshing right now.
-    fn needs_refresh(&self) -> bool;
-}
-
 /// Trait for an authentication method.
 ///
 /// An OpenStack authentication method is expected to be able to:
 ///
 /// 1. get an authentication token to use when accessing services,
 /// 2. get an endpoint URL for the given service type.
-pub trait Method: Sized {
-    /// A token type.
-    type TokenType: Token;
-
+///
+/// An authentication method should cache the token as long as it's valid.
+pub trait AuthMethod: BoxedClone + Debug {
     /// Default endpoint interface that is used when none is provided.
     fn default_endpoint_interface(&self) -> String {
         String::from("public")
@@ -45,17 +41,32 @@ pub trait Method: Sized {
     /// Default region to use with this authentication (if any).
     fn default_region(&self) -> Option<String> { None }
 
-    /// Verify authentication and generate an auth token.
-    fn get_token(&self, client: &Client) -> ApiResult<Self::TokenType>;
-
     /// Get a URL for the requested service.
-    fn get_endpoint(&self, service_type: String,
+    fn get_endpoint(&self, client: &Client,
+                    service_type: String,
                     endpoint_interface: Option<String>,
-                    region: Option<String>,
-                    session: &Session<Self>) -> ApiResult<Url>;
+                    region: Option<String>) -> ApiResult<Url>;
 
-    /// Create a session with this authentication method.
-    fn session(self) -> Session<Self> {
-        Session::new(self)
+    /// Create an authenticated request.
+    fn request<'a>(&self, client: &'a Client, method: Method, url: Url,
+                   headers: Headers) -> ApiResult<RequestBuilder<'a>>;
+}
+
+
+/// Helper trait to allow cloning of sessions.
+pub trait BoxedClone {
+    /// Clone the authentication method.
+    fn boxed_clone(&self) -> Box<AuthMethod>;
+}
+
+impl<T> BoxedClone for T where T: 'static + AuthMethod + Clone {
+    fn boxed_clone(&self) -> Box<AuthMethod> {
+        Box::new(self.clone())
+    }
+}
+
+impl Clone for Box<AuthMethod> {
+    fn clone(&self) -> Box<AuthMethod> {
+        self.boxed_clone()
     }
 }
